==> firefox-109.0b8.source.tar.xz: firefox-109.0/devtools/shared/commands/resource/legacy-listeners/websocket.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

"use strict";

const ResourceCommand = require("resource://devtools/shared/commands/resource/resource-command.js");

module.exports = async function({ targetFront, onAvailable }) {
  if (!targetFront.hasActor("webSocket")) {
    return;
  }

  const webSocketFront = await targetFront.getFront("webSocket");
  webSocketFront.startListening();

  webSocketFront.on(
    "webSocketOpened",
    (httpChannelId, effectiveURI, protocols, extensions) => {
      const resource = toResource("webSocketOpened", {
        httpChannelId,
        effectiveURI,
        protocols,
        extensions,
      });
      onAvailable([resource]);
    }
  );

  webSocketFront.on(
    "webSocketClosed",
    (httpChannelId, wasClean, code, reason) => {
      const resource = toResource("webSocketClosed", {
        httpChannelId,
        wasClean,
        code,
        reason,
      });
      onAvailable([resource]);
    }
  );

  webSocketFront.on("frameReceived", (httpChannelId, data) => {
    const resource = toResource("frameReceived", { httpChannelId, data });
    onAvailable([resource]);
  });

  webSocketFront.on("frameSent", (httpChannelId, data) => {
    const resource = toResource("frameSent", { httpChannelId, data });
    onAvailable([resource]);
  });
};

function toResource(wsMessageType, eventParams) {
  return {
    resourceType: ResourceCommand.TYPES.WEBSOCKET,
    wsMessageType,
    ...eventParams,
  };
}

==> firefox-111.0b3.source.tar.xz: firefox-111.0/devtools/shared/commands/resource/legacy-listeners/websocket.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

"use strict";

const ResourceCommand = require("resource://devtools/shared/commands/resource/resource-command.js");

// @backward-compat { version 111 } The webSocket legacy listener can be deleted
// when 111 is on the release channel.
module.exports = async function({ targetFront, onAvailable }) {
  if (!targetFront.hasActor("webSocket")) {
    return;
  }

  const webSocketFront = await targetFront.getFront("webSocket");
  webSocketFront.startListening();

  webSocketFront.on(
    "webSocketOpened",
    (httpChannelId, effectiveURI, protocols, extensions) => {
      const resource = toResource("webSocketOpened", {
        httpChannelId,
        effectiveURI,
        protocols,
        extensions,
      });
      onAvailable([resource]);
    }
  );

  webSocketFront.on(
    "webSocketClosed",
    (httpChannelId, wasClean, code, reason) => {
      const resource = toResource("webSocketClosed", {
        httpChannelId,
        wasClean,
        code,
        reason,
      });
      onAvailable([resource]);
    }
  );

  webSocketFront.on("frameReceived", (httpChannelId, data) => {
    const resource = toResource("frameReceived", { httpChannelId, data });
    onAvailable([resource]);
  });

  webSocketFront.on("frameSent", (httpChannelId, data) => {
    const resource = toResource("frameSent", { httpChannelId, data });
    onAvailable([resource]);
  });
};

function toResource(wsMessageType, eventParams) {
  return {
    resourceType: ResourceCommand.TYPES.WEBSOCKET,
    wsMessageType,
    ...eventParams,
  };
}
